@@ -62,6 +62,8 @@ Later updates (from the source web site):
 
 =item * version 0.81, published on July 3, 2006
 
+=item * version 0.82, published on July 10, 2006
+
 =back
 
 =head1 SEE ALSO
@@ -103,3 +105,4 @@ tex flashy petricia tim_zumph earl lefty sourpuss wendel_j_stone_iv
 vijay exactly_man alan andy
 lou mister_serdecisions sandeep
 patty smokin_jim betty_the_bulldozer
+amber_dextrous stinky_pete 
